dosage2vcf: Convert DArTag Dosage and Counts to VCF

View source: R/dosage2vcf.R

dosage2vcfR Documentation

Convert DArTag Dosage and Counts to VCF

Description

This function will convert the DArT Dosage Report and Counts files to VCF format

Usage

dosage2vcf(dart.report, dart.counts, ploidy, output.file)

Arguments

dart.report

Path to the DArT dosage report .csv file. Typically contains "Dosage Report" in the file name.

dart.counts

Path to the DArT counts .csv file. Typically contains "Counts" in the file name.

ploidy

The ploidy of the species being analyzed

output.file

output file name and path

Details

This function will convert the Dosage Report and Counts files from DArT into a VCF file. These two files are received directly from DArT for a given sequencing project. The output file will be saved to the location and with the name that is specified. The VCF format is v4.3

Value

A vcf file

Examples

## Use file paths for each file on the local system

#The files are directly from DArT for a given sequencing project.
#The are labeled with Dosage_Report or Counts in the file names.

#Temp location (only for example)
output_file <- tempfile()

dosage2vcf(dart.report = system.file("iris_DArT_Allele_Dose_Report_small.csv", package = "BIGr"),
           dart.counts = system.file("iris_DArT_Counts_small.csv", package = "BIGr"),
           ploidy = 2,
           output.file = output_file)

# Removing the output for the example
rm(output_file)

##The function will output the converted VCF using information from the DArT files


BIGr documentation built on Nov. 5, 2025, 6:03 p.m.