| madc2gmat | R Documentation |
Scale and normalize MADC read count data and convert it to an additive genomic relationship matrix.
madc2gmat(
madc_file,
seed = NULL,
method = "collapsed",
ploidy,
output.file = NULL
)
madc_file |
Path to the MADC file to be filtered |
seed |
Optional seed for random number generation (default is NULL) |
method |
Method to use for processing the MADC data. Options are "unique" or "collapsed". Default is "collapsed". |
ploidy |
Numeric. Ploidy level of the samples (e.g., 2 for diploid, 4 for tetraploid) |
output.file |
Path to save the filtered data (if NULL, data will not be saved) |
This function reads a MADC file, processes it to remove unnecessary columns, and then converts it into an additive genomic relationship matrix using the first method proposed by VanRaden (2008). The resulting matrix can be used for genomic selection or other genetic analyses.
data.frame or saved csv file
Alexander M. Sandercock
VanRaden, P. M. (2008). Efficient methods to compute genomic predictions. Journal of Dairy Science, 91(11), 4414-4423
#Input variables
madc_file <- system.file("example_MADC_FixedAlleleID.csv", package="BIGr")
#Calculations
temp <- tempfile()
# Converting to additive relationship matrix
gmat <- madc2gmat(madc_file,
seed = 123,
ploidy=2,
output.file = NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.