Learn R Programming

BIGr (version 0.6.2)

madc2vcf_targets: Format MADC Target Loci Read Counts Into VCF

Description

This function will extract the read count information from a MADC file target markers and convert to VCF file format.

Usage

madc2vcf_targets(madc_file, output.file, botloci_file, get_REF_ALT = FALSE)

Value

A VCF file v4.3 with the target marker read count information

A VCF file v4.3 with the target marker read count information

Arguments

madc_file

Path to MADC file

output.file

output file name and path

botloci_file

A string specifying the path to the file containing the target IDs designed in the bottom strand.

get_REF_ALT

if TRUE recovers the reference and alternative bases by comparing the sequences. If more than one polymorphism are found for a tag, it is discarded.

Details

The DArTag MADC file format is not commonly supported through existing tools. This function will extract the read count information from a MADC file for the target markers and convert it to a VCF file format for the genotyping panel target markers only

Examples

Run this code
# Load example files
madc_file <- system.file("example_MADC_FixedAlleleID.csv", package="BIGr")
bot_file <- system.file("example_SNPs_DArTag-probe-design_f180bp.botloci", package="BIGr")

#Temp location (only for example)
output_file <- tempfile()

# Convert MADC to VCF
madc2vcf_targets(madc_file = madc_file,
                 output.file = output_file,
                 get_REF_ALT = TRUE,
                 botloci_file = bot_file)

rm(output_file)

Run the code above in your browser using DataLab